@@ -17,7 +17,9 @@ test_that("output of struct_pi is of correct size and form",{
   y <- ts(x, start = 2000, frequency = 12)
   pred <- struct_pi(y, n_ahead = 5, nsim = 50)
   expect_identical(dim(pred), c(5L, 5L))
-  expect_identical(class(pred), c("mts", "ts", "matrix"))
+  expect_s3_class(pred, "mts")
+  expect_s3_class(pred, "ts")
+  expect_s3_class(pred, "matrix")
   expect_identical(frequency(pred), frequency(y))
   expect_identical(start(pred), end(y)+c(0, 1))
 })
